@@ -151,9 +151,9 @@ bool PajeContainer::keepSimulating (void)
 
 std::string PajeContainer::descriptionHeader (void) const
 {
-  std::stringstream description;
-  description << "Container, Parent, Type, Start, End, Duration, Name";
-  return description.str();
+  std::string description;
+  description = "Container, Parent, Type, Start, End, Duration, Name";
+  return description;
 }
 
 std::string PajeContainer::description (void) const
@@ -596,7 +596,7 @@ std::vector<PajeEntity*> PajeContainer::enumeratorOfEntitiesTyped (double start,
 
   std::vector<PajeEntity*>::iterator low, up, it;
   low = lower_bound (entities[type].begin(), entities[type].end(), start, PajeEntity::PajeEntityCompare());
-  up = lower_bound (entities[type].begin(), entities[type].end(), end, PajeEntity::PajeEntityCompare());
+  up = upper_bound (entities[type].begin(), entities[type].end(), end, PajeEntity::PajeEntityCompare());
 
   if (low != entities[type].begin()){
     low--;
@@ -846,13 +846,16 @@ void PajeContainer::recursiveClearCompleteEntities (std::ostream& output, bool d
     while (it != children.end()){
       PajeEntity *child = *it;
       if (child->isComplete()){
-	child->dump(output);
-	it = children.erase(it);
-	delete child;
+        child->dump(output);
+        it++;
+        delete child;
       }else{
-	break;
+        break;
       }
     }
+    if(it != children.begin()){
+      children.erase(children.begin(), it);
+    }
     entities[childEntity.first] = children;
   }
 
