@@ -59,8 +59,9 @@ void PajeFlexReader::readNextChunk()
 
 PajeFlexReader::~PajeFlexReader()
 {
-  /* print number of events */
-  printf ("%lld events and %lld lines\n", counter, yylineno);
+  fclose(yyin);
+  yylex_destroy();
+  paje_bison_parser_free();
 }
 
 void PajeFlexReader::closeReading (void)
